@@ -12,7 +12,7 @@
 -- See the License for the specific language governing permissions and
 -- limitations under the License.
 --
--- Copyright (C) 2015-present, TBOOX Open Source Group.
+-- Copyright (C) 2015-present, Xmake Open Source Community.
 --
 -- @author      DawnMagnet
 -- @file        bl51.lua
@@ -28,7 +28,7 @@ end
 
 -- make the link arguments list
 function linkargv(self, objectfiles, targetkind, targetfile, flags)
-    return self:program(), table.join(table.concat(objectfiles, ","), "TO", targetfile)
+    return self:program(), table.join(table.concat(objectfiles, ","), "TO", targetfile, flags)
 end
 
 -- link the target file
